@@ -5,11 +5,10 @@ use File::UStore;
 use strict;
 use warnings;
 
-my $store = new File::UStore(
-    path   => "/tmp/.teststore",
-    prefix => "prefix_",
-    depth  => 5
-);
+my $store = new File::UStore( path => "/tmp/.teststore", 
+                              prefix => "prefix_",
+                              depth  => 5
+                            );
 
 ### to add a file in the store
 open( my $file, "usage.pl" ) or die "Unable to open file ";
@@ -25,7 +24,7 @@ print <$FH>;
 ### where is the file in the store ?
 my $location = $store->getpath("$id");
 print "usage.pl is located on the filesystem at the following location : "
-  . $location . "\n";
+    . $location . "\n";
 
 ### remove a file from the store (based on its id)
 $store->remove("$id") or die "Unable to remove usage.pl from the store";
