@@ -7,7 +7,7 @@ use warnings;
 
 # ABSTRACT: UUID based File Storage Module.
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 # Dependencies
 
@@ -205,9 +205,23 @@ __END__
 
 File::UStore - UUID based File Storage Module.
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/shantanubhadoria/perl-File-UStore"><img src="https://api.travis-ci.org/shantanubhadoria/perl-File-UStore.svg?branch=build/master" alt="Travis status" /></a>
+<a href="http://matrix.cpantesters.org/?dist=File-UStore%200.15"><img src="https://badgedepot.code301.com/badge/cpantesters/File-UStore/0.15" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/File-UStore-0.15"><img src="https://badgedepot.code301.com/badge/kwalitee/File-UStore/0.15" alt="Distribution kwalitee" /></a>
+<a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
+</p>
+
+=end html
+
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -232,7 +246,7 @@ version 0.14
 
 =head1 DESCRIPTION
 
-File::UStore is a perl library based on File::HStore to store files on a filesystem using a UUID based randomised 
+File::UStore is a perl library based on File::HStore to store files on a filesystem using a UUID based randomized 
 storage with folder depth control over storage.File::UStore is a library that allows users to abstract file storage 
 using a UUID based pointer instead of File Hashes to store the file. This is a critical feature for code which  
 requires even duplicate files to get a unique identifier each time they are added to a store. A Hash Storage on  
@@ -339,7 +353,7 @@ Thanks to Alexandre Dulaunoy for the excellent File::HStore module which along w
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/file-ustore/issues>.
+L<https://github.com/shantanubhadoria/perl-file-ustore/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -347,9 +361,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/file-ustore>
+L<https://github.com/shantanubhadoria/perl-file-ustore>
 
-  git clone git://github.com/shantanubhadoria/file-ustore.git
+  git clone git://github.com/shantanubhadoria/perl-file-ustore.git
 
 =head1 AUTHOR
 
@@ -357,14 +371,12 @@ Shantanu Bhadoria <shantanu@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Shantanu Bhadoria
+
 =over 4
 
 =item *
 
-Shantanu <shantanu@cpan.org>
-
-=item *
-
 Shantanu Bhadoria <shantanu.bhadoria@gmail.com>
 
 =item *
@@ -375,7 +387,7 @@ Shantanu Bhadoria <shantanu@shantanu-M14xR2.(none)>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Shantanu Bhadoria.
+This software is copyright (c) 2016 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
